==> nextcloud-25.0.8.tgz: nextcloud/apps/systemtags/l10n/cs.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "Název štítku je prázdný",
    "Update" : "Aktualizovat",
    "Create" : "Vytvořit",
    "Select tag …" : "Vyberte štítek…",
    "System tag %1$s added by the system" : "Systémový štítek %1$s přidán systémem",
    "Added system tag {systemtag}" : "Přidán systémový štítek {systemtag}",
    "Added system tag %1$s" : "Přidán systémový štítek %1$s",
    "%1$s added system tag %2$s" : "%1$s přidal(a) systémový štítek %2$s",
    "{actor} added system tag {systemtag}" : "{actor} přidal(a) systémový štítek {systemtag}",
    "System tag %1$s removed by the system" : "Systémový štítek %1$s odebrán systémem",
    "Removed system tag {systemtag}" : "Odebrán systémový štítek {systemtag}",
    "Removed system tag %1$s" : "Odebrán systémový štítek %1$s",
    "%1$s removed system tag %2$s" : "%1$s odebral(a) systémový štítek %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} odebral(a) systémový štítek {systemtag}",
    "You created system tag %1$s" : "Vytvořili jste systémový štítek %1$s",
    "You created system tag {systemtag}" : "Vytvořili jste systémový štítek {systemtag}",
    "%1$s created system tag %2$s" : "%1$s vytvořil(a) systémový štítek %2$s",
    "{actor} created system tag {systemtag}" : "{actor} vytvořil(a) systémový štítek {systemtag}",
    "You deleted system tag %1$s" : "Smazali jste systémový štítek %1$s",
    "You deleted system tag {systemtag}" : "Smazali jste systémový štítek {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s smazal(a) systémový štítek %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} smazal(a) systémový štítek {systemtag}",
    "You updated system tag %2$s to %1$s" : "Aktualizovali jste systémový štítek %2$s na %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Aktualizovali jste systémový štítek {oldsystemtag} na {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s aktualizoval(a) systémový štítek %3$s na %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} aktualizoval(a) systémový štítek {oldsystemtag} na { newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Systémový štítek %2$s byl přidán k %1$s systémem",
    "System tag {systemtag} was added to {file} by the system" : "Systémový štítek {systemtag} byl přidán k {file} systémem",
    "You added system tag %2$s to %1$s" : "Přidali jste systémový štítek %2$s k %1$s",
    "You added system tag {systemtag} to {file}" : "Přidali jste systémový štítek {systemtag} k {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s přidal(a) systémový štítek %3$s k %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} přidal(a) systémový štítek {systemtag} k {file}",
    "System tag %2$s was removed from %1$s by the system" : "Systémový štítek %2$s byl odebrán z %1$s systémem",
    "System tag {systemtag} was removed from {file} by the system" : "Systémový štítek {systemtag} byl odebrán z {file} systémem",
    "You removed system tag %2$s from %1$s" : "Z %2$s jste odebrali systémový štítek %1$s",
    "You removed system tag {systemtag} from {file}" : "Z {file} jste odebrali systémový štítek {systemtag}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s odebral(a) systémový štítek %3$s z %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} odebral(a) systémový štítek {systemtag} z {file}",
    "%s (restricted)" : "%s (uživatelsky nepřiřaditelné)",
    "%s (invisible)" : "%s (neviditelný)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systémové štítky</strong> souboru byly upraveny",
    "Tags" : "Štítky",
    "All tagged %s …" : "Vše oštítkované %s …",
    "tagged %s" : "oštítkované %s",
    "Collaborative tags" : "Štítky pro spolupráci",
    "Collaborative tagging functionality which shares tags among users." : "Funkce opatřování štítky pro spolupráci, sdílenými mezi uživateli.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funkce pro opatřování štítky pro spolupráci, sdílenými mezi uživateli. Skvělé pro týmy.\n\t(Pokud jste poskytovateli instalace, sloužící více subjektům, je doporučeno tuto aplikaci vypnout, protože štítky jsou sdílené.)",
    "Loading collaborative tags …" : "Načítání štítků pro spolupráci…",
    "Search or create collaborative tags" : "Hledat nebo vytvořit štítky pro spolupráci",
    "Collaborative tags …" : "Štítky pro spolupráci…",
    "No tags to select, type to create a new tag" : "Nevybrány žádné štítky k výběru – psaním vytvořte nový",
    "Failed to load tags" : "Štítky se nepodařilo načíst",
    "Failed to load selected tags" : "Vybrané štítky se nepodařilo načíst",
    "Failed to select tag" : "Štítek se nepodařilo načíst",
    "Failed to create tag" : "Štítek se nepodařilo vytvořit",
    "Failed to delete tag" : "Štítek se nepodařilo smazat",
    "Failed to load last used tags" : "Nepodařilo se načíst nedávno použité štítky",
    "Missing \"Content-Location\" header" : "Chybí hlavička „Content-Location“",
    "Tagged files" : "Oštítkované soubory",
    "Select tags to filter by" : "Vybrat štítky pro filtr",
    "No tags found" : "Nenalezeny žádné štítky",
    "Please select tags to filter by" : "Vyberte štítky podle kterých filtrovat",
    "No files found for the selected tags" : "Pro vybrané štítky nebyly nalezeny žádné soubory",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Štítky pro spolupráci jsou k dispozici všem uživatelům. Uživatelsky nepřiřaditelné štítky jsou uživatelům viditelné, ale nemohou je přiřazovat.\nNeviditelné štítky jsou pro vnitřní potřebu, protože uživatelé je nemohou vidět ani je přiřazovat.",
    "Create a new tag" : "Vytvořit nový  štítek",
    "Name" : "Název",
    "Public" : "Veřejný",
    "Restricted" : "Uživatelsky nepřiřaditelný",
    "Invisible" : "Neviditelný",
    "Delete" : "Smazat",
    "Reset" : "Vrátit na výchozí",
    "No files in here" : "Nejsou zde žádné soubory",
    "No entries found in this folder" : "V této složce nic nenalezeno",
    "Size" : "Velikost",
    "Modified" : "Změněno"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-25.0.11.tgz: nextcloud/apps/systemtags/l10n/cs.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "Název štítku je prázdný",
    "Update" : "Aktualizovat",
    "Create" : "Vytvořit",
    "Select tag …" : "Vyberte štítek…",
    "System tag %1$s added by the system" : "Systémový štítek %1$s přidán systémem",
    "Added system tag {systemtag}" : "Přidán systémový štítek {systemtag}",
    "Added system tag %1$s" : "Přidán systémový štítek %1$s",
    "%1$s added system tag %2$s" : "%1$s přidal(a) systémový štítek %2$s",
    "{actor} added system tag {systemtag}" : "{actor} přidal(a) systémový štítek {systemtag}",
    "System tag %1$s removed by the system" : "Systémový štítek %1$s odebrán systémem",
    "Removed system tag {systemtag}" : "Odebrán systémový štítek {systemtag}",
    "Removed system tag %1$s" : "Odebrán systémový štítek %1$s",
    "%1$s removed system tag %2$s" : "%1$s odebral(a) systémový štítek %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} odebral(a) systémový štítek {systemtag}",
    "You created system tag %1$s" : "Vytvořili jste systémový štítek %1$s",
    "You created system tag {systemtag}" : "Vytvořili jste systémový štítek {systemtag}",
    "%1$s created system tag %2$s" : "%1$s vytvořil(a) systémový štítek %2$s",
    "{actor} created system tag {systemtag}" : "{actor} vytvořil(a) systémový štítek {systemtag}",
    "You deleted system tag %1$s" : "Smazali jste systémový štítek %1$s",
    "You deleted system tag {systemtag}" : "Smazali jste systémový štítek {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s smazal(a) systémový štítek %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} smazal(a) systémový štítek {systemtag}",
    "You updated system tag %2$s to %1$s" : "Aktualizovali jste systémový štítek %2$s na %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Aktualizovali jste systémový štítek {oldsystemtag} na {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s aktualizoval(a) systémový štítek %3$s na %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} aktualizoval(a) systémový štítek {oldsystemtag} na { newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Systémový štítek %2$s byl přidán k %1$s systémem",
    "System tag {systemtag} was added to {file} by the system" : "Systémový štítek {systemtag} byl přidán k {file} systémem",
    "You added system tag %2$s to %1$s" : "Přidali jste systémový štítek %2$s k %1$s",
    "You added system tag {systemtag} to {file}" : "Přidali jste systémový štítek {systemtag} k {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s přidal(a) systémový štítek %3$s k %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} přidal(a) systémový štítek {systemtag} k {file}",
    "System tag %2$s was removed from %1$s by the system" : "Systémový štítek %2$s byl odebrán z %1$s systémem",
    "System tag {systemtag} was removed from {file} by the system" : "Systémový štítek {systemtag} byl odebrán z {file} systémem",
    "You removed system tag %2$s from %1$s" : "Z %2$s jste odebrali systémový štítek %1$s",
    "You removed system tag {systemtag} from {file}" : "Z {file} jste odebrali systémový štítek {systemtag}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s odebral(a) systémový štítek %3$s z %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} odebral(a) systémový štítek {systemtag} z {file}",
    "%s (restricted)" : "%s (uživatelsky nepřiřaditelné)",
    "%s (invisible)" : "%s (neviditelný)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systémové štítky</strong> souboru byly upraveny",
    "Tags" : "Štítky",
    "All tagged %s …" : "Vše oštítkované %s …",
    "tagged %s" : "oštítkované %s",
    "Collaborative tags" : "Štítky pro spolupráci",
    "Collaborative tagging functionality which shares tags among users." : "Funkce opatřování štítky pro spolupráci, sdílenými mezi uživateli.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funkce pro opatřování štítky pro spolupráci, sdílenými mezi uživateli. Skvělé pro týmy.\n\t(Pokud jste poskytovateli instalace, sloužící více subjektům, je doporučeno tuto aplikaci vypnout, protože štítky jsou sdílené.)",
    "Loading collaborative tags …" : "Načítání štítků pro spolupráci…",
    "Search or create collaborative tags" : "Hledat nebo vytvořit štítky pro spolupráci",
    "Collaborative tags …" : "Štítky pro spolupráci…",
    "No tags to select, type to create a new tag" : "Nevybrány žádné štítky k výběru – psaním vytvořte nový",
    "Failed to load tags" : "Štítky se nepodařilo načíst",
    "Failed to load selected tags" : "Vybrané štítky se nepodařilo načíst",
    "Failed to select tag" : "Štítek se nepodařilo načíst",
    "Failed to create tag" : "Štítek se nepodařilo vytvořit",
    "Failed to delete tag" : "Štítek se nepodařilo smazat",
    "This file has the tag {tag}" : "Tento soubor má štítek {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Tento soubor má štítky {firstTags} a {lastTag}",
    "Failed to load last used tags" : "Nepodařilo se načíst nedávno použité štítky",
    "Missing \"Content-Location\" header" : "Chybí hlavička „Content-Location“",
    "Tagged files" : "Oštítkované soubory",
    "Select tags to filter by" : "Vybrat štítky pro filtr",
    "No tags found" : "Nenalezeny žádné štítky",
    "Please select tags to filter by" : "Vyberte štítky podle kterých filtrovat",
    "No files found for the selected tags" : "Pro vybrané štítky nebyly nalezeny žádné soubory",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Štítky pro spolupráci jsou k dispozici všem uživatelům. Uživatelsky nepřiřaditelné štítky jsou uživatelům viditelné, ale nemohou je přiřazovat.\nNeviditelné štítky jsou pro vnitřní potřebu, protože uživatelé je nemohou vidět ani je přiřazovat.",
    "Create a new tag" : "Vytvořit nový  štítek",
    "Name" : "Název",
    "Public" : "Veřejný",
    "Restricted" : "Uživatelsky nepřiřaditelný",
    "Invisible" : "Neviditelný",
    "Delete" : "Smazat",
    "Reset" : "Vrátit na výchozí",
    "No files in here" : "Nejsou zde žádné soubory",
    "No entries found in this folder" : "V této složce nic nenalezeno",
    "Size" : "Velikost",
    "Modified" : "Změněno"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
